import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import Alert from 'reactstrap/lib/Alert';
import Button from 'reactstrap/lib/Button';
import Container from 'reactstrap/lib/Container';
import { IconAttention } from '../../icons/icon-attention/icon-attention';
import { UNDEFINED_ERROR_ID } from '../../../constants';
import './global-alert.scss';

export const errorMessage = <FormattedMessage id={UNDEFINED_ERROR_ID} />;

export class GlobalAlert extends Component {
  state = {
    visible: true,
  };

  onDismiss = () => {
    const { onDismiss } = this.props;
    this.setState({ visible: false });
    if (onDismiss) {
      onDismiss();
    }
  };

  render() {
    return (
      <Container className="global-alert position-fixed pt-0_5">
        <Alert color="red-r30" isOpen={this.state.visible}>
          <div className="d-flex justify-content-center alert-text pr-4 pr-sm-0">
            <div className="alert-attention">
              <IconAttention />
            </div>
            {this.props.children}
          </div>
          <Button color="link" className="alert-dismiss" onClick={this.onDismiss}>&times;</Button>
        </Alert>
      </Container>
    );
  }
}

GlobalAlert.propTypes = {
  children: PropTypes.node,
  onDismiss: PropTypes.func,
};

GlobalAlert.defaultProps = {
  children: errorMessage,
  onDismiss: null,
};
