import Button from 'reactstrap/lib/Button';
import { GlobalAlert } from './global-alert';

let wrapper;
const onDismiss = jest.fn();

describe('<GlobalAlert />', () => {
  beforeEach(() => {
    wrapper = shallow(<GlobalAlert onDismiss={onDismiss} />);
    onDismiss.mockReset();
  });

  test('should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
  });

  describe('when clicking dismiss', () => {
    test('should dismiss alert', () => {
      expect(wrapper.state().visible).toBe(true);
      wrapper.find(Button).simulate('click');
      expect(wrapper.state().visible).toBe(false);
      expect(onDismiss).toHaveBeenCalledTimes(1);
    });
  });

  describe('with children', () => {
    test('should match snapshot', () => {
      expect(shallow(<GlobalAlert>Test message</GlobalAlert>)).toMatchSnapshot();
    });
  });

  describe('w/o onDismiss', () => {
    test('should match snapshot', () => {
      wrapper = shallow(<GlobalAlert />);
      wrapper.find(Button).simulate('click');
      expect(onDismiss).not.toHaveBeenCalled();
    });
  });
});
