import { LOCALE, DEFAULT_LOCALE, LOCALE_KEYS, LANG_KEYS } from '../constants';

/**
 * en: 'en-us',
 * ru: 'ru-ru'
 */
export const lang2LocaleMapping = {
  [LANG_KEYS[LOCALE_KEYS.EN_US]]: LOCALE_KEYS.EN_US,
  [LANG_KEYS[LOCALE_KEYS.ZH_CN]]: LOCALE_KEYS.ZH_CN,
  [LANG_KEYS[LOCALE_KEYS.RU_RU]]: LOCALE_KEYS.RU_RU,
  [LANG_KEYS[LOCALE_KEYS.KO_KO]]: LOCALE_KEYS.KO_KO,
};

/**
 * en-us: 'en',
 * ru-ru: 'ru'
 */
export const locale2LangMapping = {
  [LOCALE_KEYS.EN_US]: LANG_KEYS[LOCALE_KEYS.EN_US],
  [LOCALE_KEYS.ZH_CN]: LANG_KEYS[LOCALE_KEYS.ZH_CN],
  [LOCALE_KEYS.RU_RU]: LANG_KEYS[LOCALE_KEYS.RU_RU],
  [LOCALE_KEYS.KO_KO]: LANG_KEYS[LOCALE_KEYS.KO_KO],
};

/**
 * Choose locale from store
 * Pass store as argument (required for isomorphic apps)
 *
 * @param {object} store - can be either localstore key-value storage or cookie.parse(document.cookie)
 */
export const chooseLocale = (store = {}) => {
  const locale = store[LOCALE];
  return locale || DEFAULT_LOCALE;
};

/**
 * Takes route (href) and locale in full format (en-us, ko-ko, etc)
 *
 * @param {string} route
 * @param {string} locale
 */
export const wrapRoute2Locale = (route, locale) => `/${locale}${route}`;
